@@ -7,10 +7,25 @@ import os
 
 
 def get_engine():
-    print '%s' % os.path.join(os.environ.get('HOME'), 'qsc.dat')
+    dbfile = os.path.sep.join([os.environ.get('HOME'), '.config', 'qsc.dat'])
+    old_dbfile = os.path.sep.join([os.environ.get('HOME'), 'qsc.dat'])
+
+    if os.path.exists(old_dbfile) is True:
+        print('move old configuration for new destination %s' % old_dbfile)
+        src_fd = open(old_dbfile, 'rb')
+        dst_fd = open(dbfile, 'wb')
+
+        dst_fd.write(src_fd.read())
+        dst_fd.close()
+        src_fd.close()
+
+        os.unlink(old_dbfile)
+
+    print('database file %s' % dbfile)
 
     return sqlalchemy.create_engine(
-        'sqlite:///%s' % os.path.join(os.environ.get('HOME'), 'qsc.dat'),
+        'sqlite:///%s' % dbfile,
+        native_datetime=True,
         echo=False
     )
 
